summaryrefslogtreecommitdiff
path: root/include/p2sb.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/p2sb.h')
-rw-r--r--include/p2sb.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/include/p2sb.h b/include/p2sb.h
index a25170e3d1..ddbc8d5e14 100644
--- a/include/p2sb.h
+++ b/include/p2sb.h
@@ -17,11 +17,11 @@
#define PCH_P2SB_HBDF 0x70
/**
* struct p2sb_child_platdata - Information about each child of a p2sb device
*
* @pid: Port ID for this child
*/
-struct p2sb_child_platdata {
+struct p2sb_child_plat {
uint pid;
};
@@ -17,11 +17,11 @@
#define PCH_P2SB_HBDF 0x70
/**
- * struct p2sb_child_platdata - Information about each child of a p2sb device
+ * struct p2sb_child_plat - Information about each child of a p2sb device
*
* @pid: Port ID for this child